@@ -20,7 +20,7 @@ class AzureRemote(ABC):
         try:
             return self.get_from_client(self.prefix+key)
         except ResourceNotFoundError as rnf:
-            raise KeyError from rnf
+            raise KeyError(key) from rnf
 
     @abstractmethod
     def get_from_client(self,key):
